# Welcome to Pokie


[![Tests](https://github.com/oddbit-project/pokie/workflows/Tests/badge.svg?branch=master)](https://github.com/oddbit-project/pokie/actions)
[![pypi](https://img.shields.io/pypi/v/pokie.svg)](https://pypi.org/project/pokie/)
[![license](https://img.shields.io/pypi/l/pokie.svg)](https://git.oddbit.org/OddBit/pokie/src/branch/master/LICENSE)


Pokie is a Flask application boilerplate, using [Rick](https://git.oddbit.org/OddBit/rick) and 
[Rick-db](https://git.oddbit.org/OddBit/rick_db) components.

For more information, please check the [Documentation](https://oddbit-project.github.io/pokie/)
